@@ -4,12 +4,12 @@
 ## modify it under the terms of the GNU General Public License
 ## as published by the Free Software Foundation; either version 2
 ## of the License, or (at your option) any later version.
-##  
+##
 ## This program is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
-## 
+##
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
@@ -75,7 +75,7 @@ separaDados <- function(dataFrame, fieldName, percTraining=0.70, seed=NULL) {
   percentualResult = list()
   percentualResult$validacao = round(percentual, 2)
   percentualResult$treino = 1-percentualResult$validacao
-  cat("\nConcluido")
+  cat("\nConcluido\n")
   individuos = list()
   individuos$treino = dfIndividuos_treino
   individuos$validacao = dfIndividuos_validacao
